@@ -28,6 +28,8 @@
 
 #include "astyle.h"
 
+#include <QDir>
+
 #include <algorithm>
 #include <fstream>
 #include <iostream>
@@ -121,15 +123,15 @@ ASFormatter::ASFormatter()
 	shouldBreakElseIfs = false;
 #ifdef TRACEF
 	// create a trace text file
-	string filename = "tracef.txt";
-	char* env = getenv("HOME");
-	if (env != NULL)
-		filename = string(env) + string("/tracef.txt");
+	string filename = "/tracef.txt";
+	string env = QDir::homePath().toStdString();
+	if (!env.empty())
+		filename = string(env) + filename;
 	else
 	{
-		env = getenv("USERPROFILE");
-		if (env != NULL)
-			filename = string(env) + string("\\My Documents\\tracef.txt");
+		env = qgetenv("USERPROFILE").data();
+		if (!env.empty())
+			filename = env + string("\\My Documents\\tracef.txt");
 		else
 		{
 			cout << "\nCould not open tracef.txt\n" << endl;
@@ -185,7 +187,7 @@ void ASFormatter::staticInit()
  *
  * init() should be called every time a ASFormatter object is to start
  * formatting a NEW source file.
- * init() recieves a pointer to a DYNAMICALLY CREATED ASSourceIterator object
+ * init() receives a pointer to a DYNAMICALLY CREATED ASSourceIterator object
  * that will be used to iterate through the source code. This object will be
  * deleted during the ASFormatter's destruction, and thus should not be
  * deleted elsewhere.
@@ -212,6 +214,7 @@ void ASFormatter::init(ASSourceIterator *si)
 	INIT_CONTAINER(parenStack, new vector<int>);
 	parenStack->push_back(0);
 
+    ignoreStuff = false;
 	currentHeader = NULL;
 	currentLine = string("");
 	readyFormattedLine = string("");
@@ -285,6 +288,79 @@ void ASFormatter::init(ASSourceIterator *si)
 
 string ASFormatter::nextLine()
 {
+    #define next \
+        if(sourceIterator->hasMoreLines()) \
+        { \
+            currentLine = sourceIterator->nextLine(); \
+            spacePadNum = 0; \
+            charNum = 0; \
+            ++inLineNumber; \
+            if(currentLine.size() == 0) \
+                currentLine = " "; \
+            \
+            isInLineBreak = true; \
+            isVirgin = false; \
+             \
+            if (isInLineComment) \
+              isImmediatelyPostLineComment = true; \
+            isInLineComment = false; \
+             \
+            isImmediatelyPostPreprocessor = isInPreprocessor; \
+            if (previousNonWSChar != '\\') \
+                isInPreprocessor = false; \
+            currentChar = currentLine[charNum]; \
+            shouldReparseCurrentChar = true; \
+            isLineReady = false; \
+            readyFormattedLine = ""; \
+            for(int i = ret.size() - 1; i >= 0; --i) \
+            { \
+                if(!isWhiteSpace(ret[i])) \
+                { \
+                    previousNonWSChar = ret[i]; \
+                    if (!isInComment && !isInLineComment && !isInQuote \
+                      && !isImmediatelyPostComment \
+                      && !isImmediatelyPostLineComment) \
+                        previousCommandChar = previousNonWSChar; \
+                    break; \
+                } \
+            } \
+            if(ret.size()) \
+                previousChar = ret[ret.size()-1]; \
+        } \
+        else \
+            endOfCodeReached = true;
+
+    if(ignoreStuff)
+    {
+        if(currentLine.substr(0, 14) == "\01!AS/Ignore\"!!")
+        {
+            ignoreStuff = false;
+            string ret = "# ";
+            ret += QString::number(inLineNumber+2).toAscii().data();
+            ret += " \"" + fileName + "\" 2";
+            next
+            if(hasMoreLines())
+              nextLine(); // there is a mysterious line, I have to eat
+            return ret;
+        }
+        else
+        {
+            string ret = currentLine;
+            next
+            return ret;
+        }
+    }
+    else if(currentLine.substr(0, 13) == "\01!ASIgnore\"!!")
+    {
+        ignoreStuff = true;
+        string ret = "# ";
+        ret += QString::number(inLineNumber+2).toAscii().data();
+        ret += " \"" + fileName + "\"";
+        next
+        return ret;
+    }
+    #undef next
+    
 	// these are reset with each new line
 	const string *newHeader;
 	bool isInVirginLine = isVirgin;
@@ -306,7 +382,7 @@ string ASFormatter::nextLine()
 		}
 		else // stuff to do when reading a new character...
 		{
-			// make sure that a virgin '{' at the begining ofthe file will be treated as a block...
+			// make sure that a virgin '{' at the beginning ofthe file will be treated as a block...
 			if (isInVirginLine && currentChar == '{')
 				previousCommandChar = '{';
 			isPreviousCharPostComment = isCharImmediatelyPostComment;
@@ -321,7 +397,7 @@ string ASFormatter::nextLine()
 		{
 			appendCurrentChar();
 
-			// explicitely break a line when a line comment's end is found.
+			// explicitly break a line when a line comment's end is found.
 			if (charNum + 1 == (int) currentLine.length())
 			{
 				isInLineBreak = true;
@@ -401,7 +477,7 @@ string ASFormatter::nextLine()
 			formattedLineCommentNum = formattedLine.length();
 			appendSequence(AS_OPEN_LINE_COMMENT);
 			goForward(1);
-			// explicitely break a line when a line comment's end is found.
+			// explicitly break a line when a line comment's end is found.
 			if (charNum + 1 == (int) currentLine.length())
 			{
 				isInLineBreak = true;
@@ -432,7 +508,7 @@ string ASFormatter::nextLine()
 		/* not in quote or comment or white-space of any type ... */
 
 		// check if in preprocessor
-		// ** isInPreprocessor will be automatically reset at the begining
+		// ** isInPreprocessor will be automatically reset at the beginning
 		//    of a new line in getnextChar()
 		if (currentChar == '#')
 		{
@@ -1205,7 +1281,7 @@ bool ASFormatter::isBeforeLineEndComment(int startPos) const
 * get the next character, increasing the current placement in the process.
 * the new character is inserted into the variable currentChar.
 *
-* @return   whether succeded to recieve the new character.
+* @return   whether succeeded to receive the new character.
 */
 bool ASFormatter::getNextChar()
 {
