@@ -1,6 +1,7 @@
-/* This file is part of kdev-pg
+/* This file is part of kdev-pg-qt
    Copyright (C) 2005 Roberto Raggi <roberto@kdevelop.org>
    Copyright (C) 2006 Jakob Petsovits <jpetso@gmx.at>
+   Copyright (C) 2010 Jonathan Schmidt-Dominé <devel@the-user.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,25 +25,16 @@
 #include <QtCore/QDebug>
 #include <QtCore/QStack>
 #include <QtCore/QStringList>
+#include "kdev-pg-pretty-printer.h"
 
 namespace KDevPG
 {
-  void generateCondition(World::NodeSet const &s, QTextStream& out)
+  extern QTextStream checkOut;
+  
+  void generateConditionFromStrings(QStringList &tokens, bool zerop, QTextStream& out)
   {
-    bool initial = true;
-    Model::Node *item = globalSystem.zero();
-
-    QStringList tokens;
-    World::NodeSet::const_iterator it = s.begin();
-    while (it != s.end())
-      {
-        item = *it;
-        ++it;
-
-        if (Model::TerminalItem *t = nodeCast<Model::TerminalItem*>(item))
-          tokens << t->mName;
-      }
     tokens.sort();
+    bool initial = true;
     foreach (const QString &token, tokens)
       {
         if (!initial)
@@ -53,14 +45,47 @@ namespace KDevPG
       }
 
 
-    if (initial && isZero(item))
+    if (initial && zerop)
       out << "true /*epsilon*/";
   }
 
+  void generateCondition(const World::NodeSet& s, QTextStream& out)
+  {
+    if(s.size() == 0 || s.size() == 1 && nodeCast<Model::ZeroItem*>(*s.begin()) != 0)
+    {
+      out << "true /*epsilon*/";
+      return;
+    }
+    
+    Model::Node *item = globalSystem.zero();
+    
+    QStringList tokens;
+    World::NodeSet::const_iterator it = s.begin();
+    while (it != s.end())
+    {
+      item = *it;
+      ++it;
+      
+      if (Model::TerminalItem *t = nodeCast<Model::TerminalItem*>(item))
+        tokens << t->mName;
+    }
+    generateConditionFromStrings(tokens, false, out);
+  }
+
   void generateTestCondition(Model::Node *node, QTextStream& out)
   {
-    World::NodeSet s = globalSystem.first(node);
-    generateCondition(s, out);
+    if(node->kind == Model::NodeKindTerminal)
+    {
+      QStringList tokens;
+      tokens << ((Model::TerminalItem*)node)->mName;
+      generateConditionFromStrings(tokens, false, out);
+    }
+    else
+    {
+      World::NodeSet& s = globalSystem.first(node);
+      
+      generateCondition(s, out);
+    }
   }
 
   QString generateParserCall(Model::NonTerminalItem *node, int catch_id, QTextStream& out)
@@ -71,7 +96,7 @@ namespace KDevPG
 
     QString capSymbolName = node->mSymbol->mCapitalizedName;
 
-    if (globalSystem.GenerateAst)
+    if (globalSystem.generateAst)
       {
         sprintf(__var, "__node_%d", __id);
         ++__id;
@@ -145,7 +170,7 @@ namespace KDevPG
     Model::Node *item = globalSystem.zero();
 
     out << "if (try_startToken_" << catch_id
-        << " == tokenStream->index() - 1)" << endl
+        << " == tokenStream->index() - 1  && yytoken != Token_EOF)" << endl
         << "yylex();" << endl
         << endl;
 
@@ -322,7 +347,7 @@ void CodeGenerator::visitEvolve(Model::EvolveItem *node)
 
   visitNode(node->mItem);
 
-  if (node == globalSystem.start)
+  if (globalSystem.start.contains(node->mSymbol))
     out << "if (Token_EOF != yytoken) { return false; }" << endl;
 
   out << "}" << endl;
@@ -411,9 +436,9 @@ void CodeGenerator::visitAlias(Model::AliasItem *node)
 
 void CodeGenerator::visitAnnotation(Model::AnnotationItem *node)
 {
-  if (!globalSystem.GenerateAst)
+  if (!globalSystem.generateAst)
     {
-      // qDebug() << "** WARNING annotation ignored" << endl;
+      // checkOut << "** WARNING annotation ignored" << endl;
       visitNode(node->mItem);
       return;
     }
@@ -534,85 +559,217 @@ void CodeGenerator::visitAnnotation(Model::AnnotationItem *node)
 
 void CodeGenerator::visitOperator(Model::OperatorItem *node)
 {
-  // generateTestCondition(node, out)
-//   out << "if(";
-//   generateTestCondition(node, out);
-//   out << ")";
   out << "bool expectOperator = false;"
       << "while(true) {"
       << "if(expectOperator) {"
       << " ";
-  const QString nodeType = capitalized(node->mName) + "Ast";    /// @TODO Add a unique name
+  const QString capNode = capitalized(node->mName);
+  const QString nodeType = capNode + "Ast";
   const QString baseNameC = node->mBase->mSymbol->mCapitalizedName;
   const QString baseType = baseNameC + "Ast";
+  Model::NonTerminalItem ntItem;
+  ntItem.mSymbol = mSym;
+  ntItem.kind = Model::NodeKindNonTerminal;
+  {
+    QTextStream argStr(&ntItem.mArguments);
+    GenerateRecursiveDelegation del(argStr);
+  }
   bool printElse = false;
-  for(__typeof__(node->mPost.begin()) i = node->mPost.begin(); i != node->mPost.end(); ++i)
+  for(auto i = node->mPost.begin(); i != node->mPost.end(); ++i)
   {
     if(printElse)
       out << "else ";
     printElse = true;
-    out << "if(yytoken == Token_" << i->op.mTok;
+    out << "if(";
+    generateTestCondition(i->op.mTok, out);
     if(i->op.mCond.size() != 0)
       out << " && " << i->op.mCond;
     out << ") { const unsigned int priority = " << i->priority << ";";
     out << i->op.mCode;
     out << "AstNode *last = 0; bool br = false;";
-    out << "while(priority " << (i->left ? "<=" : "<") << " opStack.last().p) {";
-    out << "if(opStack.size() == 1) { opStack.pop_back(); opStack.push_front(OperatorStackItem(new Postfix" << nodeType << "(last), priority)); br = true; break; } else { last = opStack.last().n; opStack.pop_back(); }}";
-    out << "if(!br) { opStack.push_back(OperatorStackItem(new Postfix" << nodeType << "(last), priority)); } yylex(); }";
+    out << "while(priority < opStack.last().p + " << i->left << ") {";
+    out << "if(opStack.size() == 1) {"
+           "if(last)\n"
+           "opStack.last().n->endToken = last->endToken;"
+           "last = opStack.last().n;"
+           "opStack.pop_back();"
+           "opStack.push_front(OperatorStackItem((*yynode) = create<Postfix"<< nodeType << ">(last), -2));"
+           "(*yynode)->endToken = last->endToken + 1;"
+           "(*yynode)->startToken = last->startToken;"
+           "br = true; break; } else {"
+           "AstNode *olast = last;"
+           "last = opStack.last().n;\n"
+           "if(olast)\nlast->endToken = olast->endToken;"
+           "opStack.pop_back(); }}";
+    out << "if(!br) { "
+           "opStack.last().n->endToken = last->endToken;"
+        << "AstNode*& ref = opStack.last().n->kind == AstNode::Binary" << capNode << "Kind && ((Binary" << nodeType << "*)opStack.last().n)->second ? ((Binary" << nodeType << "*)opStack.last().n)->second : ((Binary" << nodeType << "*)opStack.last().n)->first;\n"
+        << "opStack.push_back(OperatorStackItem(ref = create<Postfix" << nodeType << ">(last), -2));"
+          "ref->endToken = last->endToken + 1;"
+          "ref->startToken = last->startToken;"
+          "} yylex(); }";
   }
-  for(__typeof__(node->mBin.begin()) i = node->mBin.begin(); i != node->mBin.end(); ++i)
+  for(auto i = node->mBin.begin(); i != node->mBin.end(); ++i)
   {
     if(printElse)
       out << "else ";
     printElse = true;
-    out << "if(yytoken == Token_" << i->op.mTok;
+    out << "if(";
+    generateTestCondition(i->op.mTok, out);
     if(i->op.mCond.size() != 0)
       out << " && " << i->op.mCond;
     out << ") { const unsigned int priority = " << i->priority << ";";
     out << i->op.mCode;
     out << "AstNode *last = 0; bool br = false;";
-    out << "while(priority " << (i->left ? "<=" : "<") << " opStack.last().p) {";
-    out << "if(opStack.size() == 1) { opStack.pop_back(); opStack.push_front(OperatorStackItem(new Binary" << nodeType << "(last, 0), priority)); br = true; break; } else { last = opStack.last().n; opStack.pop_back(); }}";
-    out << "if(!br) { opStack.push_back(OperatorStackItem(new Binary" << nodeType << "(last, 0), priority)); } expectOperator = false; yylex(); }";
+    out << "while(priority < opStack.last().p + " << i->left << ") {";
+    out << "if(opStack.size() == 1) {"
+           "if(last)\n"
+           "opStack.last().n->endToken = last->endToken;"
+           "last = opStack.last().n;\n"
+           "opStack.pop_back();"
+           "opStack.push_front(OperatorStackItem((*yynode) = create<Binary" << nodeType << ">(last), priority));"
+           "(*yynode)->startToken = last->startToken;"
+           "br = true; break; } else {"
+           "AstNode *olast = last;"
+           "last = opStack.last().n;\n"
+           "if(olast)\nlast->endToken = olast->endToken;"
+           "opStack.pop_back(); }}";
+    out << "if(!br) { "
+           "opStack.last().n->endToken = last->endToken;"
+        << "AstNode*& ref = "
+           "opStack.last().n->kind == AstNode::Ternary" << capNode << "Kind"
+           "  ? (((Ternary" << nodeType << "*)opStack.last().n)->third"
+           "   ? ((Ternary" << nodeType << "*)opStack.last().n)->third"
+           "   : (((Ternary" << nodeType << "*)opStack.last().n)->second"
+           "    ? ((Ternary" << nodeType << "*)opStack.last().n)->second"
+           "    : ((Ternary" << nodeType << "*)opStack.last().n)->first ))"
+           "  : opStack.last().n->kind == AstNode::Binary" << capNode << "Kind"
+           " && ((Binary" << nodeType << "*)opStack.last().n)->second"
+           "  ? ((Binary" << nodeType << "*)opStack.last().n)->second"
+           "  : ((Binary" << nodeType << "*)opStack.last().n)->first;\n"
+        << "opStack.push_back(OperatorStackItem(ref = create<Binary" << nodeType << ">(last), priority)); ref->startToken = last->startToken; } expectOperator = false; yylex(); }";
   }
-  /*for(__typeof__(node->mTern.begin()) i = node->mTern.begin(); i != node->mTern.end(); ++i)
+  for(auto i = node->mTern.begin(); i != node->mTern.end(); ++i)
   {
     if(printElse)
       out << "else ";
     printElse = true;
-    out << "if(yytoken == Token_" << i->first.mTok;
+    out << "if(";
+    generateTestCondition(i->first.mTok, out);
     if(i->first.mCond.size() != 0)
-      out << " && " << i->op.mCond;
-    out << ") { const unsigned int priority = " << i->priority << ";";
-    out << i->first.mCode << "...}";
-  }*/
-  /*for(__typeof__(node->mParen.begin()) i = node->mParen.begin(); i != node->mParen.end(); ++i)
-  {
-    out << "if(yytoken == Token_" << i->second.mTok;
+      out << " && " << i->first.mCond;
+        out << ") { const unsigned int priority = " << i->priority << ";";
+    out << i->first.mCode;
+    out << "AstNode *last = 0; bool br = false;";
+    out << "while(priority < opStack.last().p + " << i->left << ") {";
+    out << "if(opStack.size() == 1) {"
+           "if(last)\n"
+           "opStack.last().n->endToken = last->endToken;"
+           "last = opStack.last().n;\n"
+           "opStack.pop_back();"
+           "opStack.push_front(OperatorStackItem((*yynode) = create<Ternary" << nodeType << ">(last), priority));"
+           "(*yynode)->startToken = last->startToken;"
+           "yylex();";
+    QString __var = generateParserCall(&ntItem, mCurrentCatchId, out);
+    out << "if(!(";
+    generateTestCondition(i->second.mTok, out);
     if(i->second.mCond.size() != 0)
       out << " && " << i->second.mCond;
-    out << ") {" << i->second.mCode << "... }";
-  }*/
-  /// @TODO TernOp, Paren (e.g. a variable instead of "1" in "opStack.size() == 1", return after ")")
-  if(printElse)
-    out << "else ";
+    out << ")) return false;"
+           "((Ternary" << nodeType << "*)*yynode)->second = "
+        << __var
+        << ";br = true; break; } else {"
+           "AstNode *olast = last;"
+           "last = opStack.last().n;\n"
+           "if(olast)\nlast->endToken = olast->endToken;"
+           "opStack.pop_back(); }}";
+    out << "if(!br) { "
+           "opStack.last().n->endToken = last->endToken;"
+        << "AstNode*& ref = "
+           "opStack.last().n->kind == AstNode::Ternary" << capNode << "Kind"
+           "  ? (((Ternary" << nodeType << "*)opStack.last().n)->third"
+           "   ? ((Ternary" << nodeType << "*)opStack.last().n)->third"
+           "   : (((Ternary" << nodeType << "*)opStack.last().n)->second"
+           "    ? ((Ternary" << nodeType << "*)opStack.last().n)->second"
+           "    : ((Ternary" << nodeType << "*)opStack.last().n)->first ))"
+           "  : opStack.last().n->kind == AstNode::Binary" << capNode << "Kind"
+           " && ((Binary" << nodeType << "*)opStack.last().n)->second"
+           "  ? ((Binary" << nodeType << "*)opStack.last().n)->second"
+           "  : ((Binary" << nodeType << "*)opStack.last().n)->first;\n"
+        << "opStack.push_back(OperatorStackItem(ref = create<Ternary" << nodeType << ">(last), priority)); ref->startToken = last->startToken; } expectOperator = false; yylex(); }";
+  }
+  out << "else ";
   out << "break;";
   out << "} else {";
   printElse = false;
-  /// @TODO Paren, Prefix, Normal
-  for(__typeof__(node->mPre.begin()) i = node->mPre.begin(); i != node->mPre.end(); ++i)
+  for(auto i = node->mPre.begin(); i != node->mPre.end(); ++i)
   {
     if(printElse)
       out << "else ";
     printElse = true;
-    out << "if(yytoken == " << i->op.mTok;
+    out << "if(";
+    generateTestCondition(i->op.mTok, out);
     if(i->op.mCond.size() != 0)
       out << " && " << i->op.mCond;
     out << ") { const unsigned int priority = " << i->priority << ";";
-    out << i->op.mCode;
-    out << "...";
-    out << "}";
+    out << i->op.mCode
+        << "Prefix" << nodeType << " *node = create<Prefix" << nodeType << ">();"
+           "if(opStack.empty())\n"
+           "(*yynode) = node;"
+           "else"
+           "{\n"
+           "void *last = opStack.last().n;"
+           "if(reinterpret_cast<Prefix" << nodeType << "*>(last)->first == 0)\n"
+           "reinterpret_cast<Prefix" << nodeType << "*>(last)->first = node;"
+           "else if(reinterpret_cast<Binary" << nodeType << "*>(last)->second == 0)\n"
+           "reinterpret_cast<Binary" << nodeType << "*>(last)->second = node;"
+           "else\n"
+           "reinterpret_cast<Ternary" << nodeType << "*>(last)->third = node;"
+           "}"
+           "opStack.push_back(OperatorStackItem(node, priority));"
+           "node->startToken = tokenStream->index() - 1;"
+           "yylex();"
+           "}" << endl;
+  }
+  for(auto i = node->mParen.begin(); i != node->mParen.end(); ++i)
+  {
+    if(printElse)
+      out << "else ";
+    printElse = true;
+    out << "if(";
+    generateTestCondition(i->first.mTok, out);
+    if(i->first.mCond.size() != 0)
+      out << " && " << i->first.mCond;
+    out << ") { yylex();"
+           "if(";
+    generateTestCondition(mSym, out);
+    out << ") {";
+    QString __var = generateParserCall(&ntItem, mCurrentCatchId, out);
+    out << "if(!(";
+    generateTestCondition(i->second.mTok, out);
+    if(i->second.mCond.size() != 0)
+      out << " && " << i->second.mCond;
+    out << ")) {"
+           "return false;"
+           "}"
+           "--" << __var << "->startToken;"
+           "++" << __var << "->endToken;"
+           "yylex();";
+    #define PUSH_UNARY \
+        out << "\
+if(!opStack.isEmpty())\
+{\
+  void *last = opStack.last().n;\
+  if(reinterpret_cast<Prefix" << nodeType << "*>(last)->first == 0)\n\
+    reinterpret_cast<Prefix" << nodeType << "*>(last)->first = " << __var << ";" << endl; \
+  out << "else if(reinterpret_cast<Binary" << nodeType << "*>(last)->second == 0)\n\
+  reinterpret_cast<Binary" << nodeType << "*>(last)->second = " << __var << ";\
+  else\nreinterpret_cast<Ternary" << nodeType << "*>(last)->third = " << __var << ";}\
+else\n\
+(*yynode) = " << __var << ";\
+opStack.push_back(OperatorStackItem(" << __var << ", -2));";
+    PUSH_UNARY
+    out << "expectOperator = true; } else\nreturn false; }";
   }
   if(printElse)
     out << "else ";
@@ -620,39 +777,14 @@ void CodeGenerator::visitOperator(Model::OperatorItem *node)
   generateTestCondition(node->mBase->mSymbol, out);
   out << ") { ";
   QString __var = generateParserCall(node->mBase, mCurrentCatchId, out);
-  out << "\
-if(!opStack.isEmpty())\
-{\
-  void *last = opStack.last().first;\
-  if(reinterpret_cast<Unary" << nodeType << "*>(last)->first == 0)\
-    reinterpret_cast<Unary" << nodeType << "*>(last)->first = " << __var << ";" << endl;
-  out << "else reinterpret_cast<Binary" << nodeType << "*>(last)->second = ptr;\
-  opStack.push_back(OperatorStackItem(" << __var << ", -1));} }";
-  /*for(__typeof__(node->mParen.begin()) i = node->mParen.begin(); i != node->mParen.end(); ++i)
-  {
-    if(printElse)
-      out << "else ";
-    printElse = true;
-    out << "if(yytoken == Token_" << i->first.mTok;
-    if(i->first.mCond.size() != 0)
-      out << " && " << i->first.mCond;
-    out << ") { " << i->first.mCode << " }";
-  }*/
-  /*for(__typeof__(node->mPre.begin()) i = node->mPre.begin(); i != node->mPre.end(); ++i)
-  {
-    if(printElse)
-      out << "else ";
-    printElse = true;
-    out << "if(yytoken == Token_" << i->op.mTok;
-    if(i->op.mCond.size() != 0)
-      out << " && " << i->op.mCond;
-    out << ") { const unsigned int priority = " << i->priority << ";";
-    out << i->op.mCode;
-    out << "... }";
-  }*/
-  out << "else ";
-  out << "break;";
-  out << "} }";
+  PUSH_UNARY
+  #undef PUSH_UNARY
+  out << "expectOperator = true; }";
+  out << "else"
+         "{"
+         "expectedSymbol(AstNode::" << capNode << "Kind"
+         ", \"" << node->mName << "\");return false;"
+         "} } }";
   /// @TODO Further: empty binary operator
 }
 
@@ -672,7 +804,7 @@ void GenerateParserRule::operator()(QPair<QString, Model::SymbolItem*> const &__
 {
   mNames.clear();
   Model::SymbolItem *sym = __it.second;
-  CodeGenerator cg(out, &mNames);
+  CodeGenerator cg(out, &mNames, sym);
 
   out << "bool Parser::parse" << sym->mCapitalizedName << "(";
 
@@ -682,14 +814,19 @@ void GenerateParserRule::operator()(QPair<QString, Model::SymbolItem*> const &__
   out << ")" << endl
       << "{" << endl;
 
-  if (globalSystem.GenerateAst)
+  if (globalSystem.generateAst)
     {
-      out << "*yynode = create<" << sym->mCapitalizedName << "Ast" << ">();" << endl << endl
-          << "(*yynode)->startToken = tokenStream->index() - 1;" << endl;
-      //Generate initialization for this ast nodes token-members using -1 as invalid value
-      GenerateTokenVariableInitialization gentokenvar( out );
-      gentokenvar(sym);
-      out << endl;
+      if(isOperatorSymbol(sym))
+        out << "QVector<OperatorStackItem> opStack;" << endl;
+      else
+      {
+        out << "*yynode = create<" << sym->mCapitalizedName << "Ast" << ">();" << endl << endl
+            << "(*yynode)->startToken = tokenStream->index() - 1;" << endl;
+        //Generate initialization for this ast nodes token-members using -1 as invalid value
+        GenerateTokenVariableInitialization gentokenvar( out );
+        gentokenvar(sym);
+        out << endl;
+      }
     }
 
   World::Environment::iterator it = globalSystem.env.find(sym);
@@ -725,10 +862,25 @@ void GenerateParserRule::operator()(QPair<QString, Model::SymbolItem*> const &__
       << endl;
 
 
-  if (globalSystem.GenerateAst)
+  if (globalSystem.generateAst)
     {
-      out << "(*yynode)->endToken = tokenStream->index() - 2;" << endl
-          << endl;
+      if(isOperatorSymbol(sym))
+      {
+        out << "AstNode *olast, *last = 0;"
+               "while(!opStack.empty())\n"
+               "{"
+               "olast = last;"
+               "last = opStack.last().n;"
+               "if(olast)\n"
+               "last->endToken = olast->endToken;"
+               "opStack.pop_back();"
+               "}" << endl;
+      }
+      else
+      {
+        out << "(*yynode)->endToken = tokenStream->index() - 2;" << endl
+            << endl;
+      }
     }
 
   out << "return true;" << endl
@@ -749,7 +901,7 @@ void GenerateLocalDeclarations::visitVariableDeclaration(Model::VariableDeclarat
     {
       if ((mNames == 0) || mNames->find(node->mName) == mNames->end())
         {
-          GenerateVariableDeclaration gen_var_decl(out);
+          GenerateVariableDeclaration<true, true> gen_var_decl(out);
           gen_var_decl(node);
 
           if (node->mVariableType == Model::VariableDeclarationItem::TypeToken
@@ -769,7 +921,7 @@ void GenerateLocalDeclarations::visitVariableDeclaration(Model::VariableDeclarat
   // for argument member nodes and tokens, check if their index precedes the current one
   else if (node->mStorageType == Model::VariableDeclarationItem::StorageAstMember
            && node->mDeclarationType == Model::VariableDeclarationItem::DeclarationArgument
-           && globalSystem.GenerateAst)
+           && globalSystem.generateAst)
     {
       QString sequence_suffix = (node->mIsSequence) ? "Sequence" : "";
 
@@ -805,7 +957,7 @@ void GenerateLocalDeclarations::visitVariableDeclaration(Model::VariableDeclarat
 
 void GenerateParseMethodSignature::operator()(Model::SymbolItem* sym)
 {
-  if (globalSystem.GenerateAst)
+  if (globalSystem.generateAst)
     {
       out << sym->mCapitalizedName << "Ast **yynode";
       firstParameter = false;
@@ -822,18 +974,36 @@ void GenerateParseMethodSignature::operator()(Model::SymbolItem* sym)
     }
 }
 
+void GenerateRecursiveDelegation::operator()(Model::SymbolItem* node)
+{
+  World::Environment::iterator it = globalSystem.env.find(node);
+  if (it != globalSystem.env.end())
+  {
+    // this creates the method signature using just the first of
+    // possibly multiple rules with the same name.
+    Model::EvolveItem *e = (*it);
+    Model::VariableDeclarationItem *decl = e->mDeclarations;
+    GenerateVariableDeclaration<false, true> vd(out);
+    while(decl)
+    {
+      vd(decl);
+      decl = decl->mNext;
+    }
+  }
+}
+
 void GenerateParseMethodSignature::visitVariableDeclaration(Model::VariableDeclarationItem *node)
 {
   if (node->mDeclarationType == Model::VariableDeclarationItem::DeclarationArgument)
     {
-      if (globalSystem.GenerateAst || (node->mStorageType != Model::VariableDeclarationItem::StorageAstMember))
+      if (globalSystem.generateAst || (node->mStorageType != Model::VariableDeclarationItem::StorageAstMember))
         {
           if (firstParameter)
             firstParameter = false;
           else
             out << ", ";
 
-          GenerateVariableDeclaration gen_var_decl(out);
+          GenerateVariableDeclaration<true, true> gen_var_decl(out);
           gen_var_decl(node);
 
           if (mNames != 0)
@@ -844,28 +1014,35 @@ void GenerateParseMethodSignature::visitVariableDeclaration(Model::VariableDecla
   DefaultVisitor::visitVariableDeclaration(node);
 }
 
-void GenerateVariableDeclaration::operator()(Model::VariableDeclarationItem *node)
+template<bool printType, bool printName>
+void GenerateVariableDeclaration<printType, printName>::operator()(Model::VariableDeclarationItem *node)
 {
-  if (node->mIsSequence)
-    out << "const KDevPG::ListNode<";
-
-  if (node->mVariableType == Model::VariableDeclarationItem::TypeToken)
-    out << "qint64 ";
-  else if (node->mVariableType == Model::VariableDeclarationItem::TypeNode)
+  if(printType)
   {
-    out << node->mCapitalizedType << "Ast *";
-  }else if (node->mVariableType == Model::VariableDeclarationItem::TypeVariable)
-    out << node->mType << " ";
-  else
-    Q_ASSERT(0); // ### not supported
+    if (node->mIsSequence)
+      out << "const KDevPG::ListNode<";
 
-  if (node->mIsSequence)
-    out << "> *";
+    if (node->mVariableType == Model::VariableDeclarationItem::TypeToken)
+      out << "qint64 ";
+    else if (node->mVariableType == Model::VariableDeclarationItem::TypeNode)
+    {
+      out << node->mCapitalizedType << "Ast *";
+    }else if (node->mVariableType == Model::VariableDeclarationItem::TypeVariable)
+      out << node->mType << " ";
+    else
+      Q_ASSERT(0); // ### not supported
 
-  out << node->mName;
+    if (node->mIsSequence)
+      out << "> *";
+  }
 
-  if (node->mIsSequence)
-    out << "Sequence";
+  if(printName)
+  {
+    out << node->mName;
+
+    if (node->mIsSequence)
+      out << "Sequence";
+  }
 }
 
 void GenerateToken::operator()(QPair<QString, Model::TerminalItem*> const &__it)
@@ -902,10 +1079,14 @@ void GenerateParserDeclarations::operator()()
       << globalSystem.tokenStream << " *tokenStream;" << endl
       << "int yytoken;" << endl;
   if(globalSystem.needOperatorStack)
-    out << "struct OperatorStackItem{AstNode *n; int unsigned p; inline OperatorStackItem(AstNode *n, int unsigned p) : n(n), p(p) {} };\
-QVector<OperatorStackItem> opStack;" << endl;
-  out
-      << endl
+    out << "struct OperatorStackItem{AstNode *n; int unsigned p;"
+           "inline OperatorStackItem(AstNode *n, int unsigned p)\n"
+           ": n(n), p(p)\n{}\n"
+           "inline OperatorStackItem()\n{}\n"
+           "inline OperatorStackItem(const OperatorStackItem& o)\n"
+           ": n(o.n), p(o.p)\n"
+           "{}\n};" << endl;
+  out << endl
       << "inline Token LA(qint64 k = 1) const" << endl
       << "{ return tokenStream->token(tokenStream->index() - 1 + k - 1); }"
       << endl
@@ -936,7 +1117,7 @@ QVector<OperatorStackItem> opStack;" << endl;
 
   out << endl;
 
-    if (globalSystem.GenerateAst)
+    if (globalSystem.generateAst)
       {
         out << "// memory pool" << endl
             << "typedef KDevPG::MemoryPool memoryPoolType;" << endl
@@ -950,7 +1131,15 @@ QVector<OperatorStackItem> opStack;" << endl;
             << "T *node = new (memoryPool->allocate(sizeof(T))) T();" << endl
             << "node->kind = T::KIND;" << endl
             << "return node;" << endl
-            << "}" << endl << endl;
+            << "}" << endl
+            << "template <class T>" << endl
+            << "inline T *create(AstNode *u)" << endl
+            << "{" << endl
+            << "T *node = new (memoryPool->allocate(sizeof(T))) T(u);" << endl
+            << "node->kind = T::KIND;" << endl
+            << "return node;" << endl
+            << "}" << endl
+            << endl;
       }
 
 
@@ -996,7 +1185,7 @@ QVector<OperatorStackItem> opStack;" << endl;
     }
 
   out << "Parser() {" << endl;
-  if (globalSystem.GenerateAst)
+  if (globalSystem.generateAst)
     {
       out << "memoryPool = 0;" << endl;
     }
